PicomotorController8742 - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# PicomotorController8742

From: Newport

Class: `herosdevices.hardware.newport.picomotor.PicomotorController8742`

Driver Quality Index: alpha

HEROS driver for 4-channel picomotor controller 8742.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.newport.picomotor.PicomotorController8742` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
host | <class ‘str’> |  | IP address of the controller, e.g. “192.168.1.42”.
port | <class ‘int’> | 23 | listening port, typically 23.
timeout | <class ‘int’> | 5000 |

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `PicomotorController8742` using BOSS.

    {
        "_id": "my_PicomotorController8742",
        "classname": "herosdevices.hardware.newport.picomotor.PicomotorController8742",
        "arguments": {
            "host": "<class 'str'>",
            "port": 23,
            "timeout": 5000
        }
    }

generated from signature

Inheritance